The dataset herein is the source code and inputs required to reproduce the 3D volumetric data describing the energy density of photons with a simulated environment and the heatmaps and journey lengths for ensembles of weighted random walkers experiencing the specific simulated environments. This documentation will a) explain the contents of this deposited dataset, and b) provide a walkthrough of the steps to reproduce the outputs used in the publication the accompanying publication. 

The deposit consists of three components:

- The input data for our Monte Carlo radiative transfer code, including configuration files, including spectra (.json5), photometric data for luminaires (.ldt), and geometry (.obj). 
- The version of our Monte Carlo Radiative Transfer solver (mcrt) and supporting library (*Aetherus*) that was used to generate the outputs used in the publication (0.2.0), supplied as Rust (.rs) source code.
- A snapshot of the source code of our grid_walker code (v0.1.0) that was used to perform the weighted random walks. 
-  A directory of scripts, titled `scripts`, to automate some of the tasks required to reproduce results in the article. 

The resulting outputs were used in the publication ‘**Changing streetlighting schemes and the ecological availability of darkness’** [DOI to follow].

Should you have problems with or questions regarding the usage of this resource, please contact Sam Morrell at [s.a.f.morrell@exeter.ac.uk](mailto:s.a.f.morrell@exeter.ac.uk). 

# Setup

## External Datasets

To reproduce the data herein, we require LiDAR data from the Defra National LIDAR Programme 2020 1m, available at https://environment.data.gov.uk/survey. The tile that contains our study plot is titled ‘*national_lidar_programme_dtm-2020-1-SX99sw’* (available at https://api.agrimetrics.co.uk/tiles/collections/survey/national_lidar_programme_dtm/2020/1/SX9090?subscription-key=public), with the file itself being called ‘**DTM_SX9090_P_10601_20200322_20200322.tif’. Place this file, and its accompanying **.tfw** file in the root directory of the dataset. 

## Monte Carlo Radiative Transfer Solver

To compile the MCRT solver, you will require the an installation of the Rust compiler toolchain, which can be installed from https://rustup.rs/. We compiled the code with Rust version 1.68.1. To compile the code we require the following libraries (along with the versions that we used for our installation in brackets):

- libnetcdf (v4.6.0)
- libpng (v1.5.13)

First, decompress the source code by navigating to the `mcrt` directory and running.

```shell
tar -zxvf aetherus-0.2.0.tar.gz
```

Now, navigate into the newly created `Aetherus-0.2.0` directory and run

```shell
cargo build
```

to build the library and MCRT binary, which can be found in `target/debug/mcrt`. 

This code comes with a suite of unit tests, which can be run using cargo by using 

```shell
cargo test
```

The README file for this code can be found at `Aetherus-0.2.0/aetherus-0.2.0-README.md`. 

## 1.3   Weighted Random Walking Code

To run the random walk code you will require an installation of Python 3 (developed and run using Python 3.10.12). To setup the virtual environment for code, which contains all of the packages required to run it, run the following commands from the root directory of the dataset. 

```python
# Untar the source code if you have not already. 
tar -zxvf grid_walker-0.1.0.tar.gz

# change into the grid_walker directory if not already there. 
cd grid_walker-0.1.0

# Setup the virtual environment in the grid_walker directory. 
python -m venv venv
source venv/bin/activate
pip install -r requirements.txt
```

Details about the code itself, as well as a description of its avaiable configuration options, ca be found in its README file at `grid_walker-0.1.0/grid_walker-0.1.0-README.md`. 

# Reproducing the Outputs

First, you must perform the MCRT simulations to produce the outputs. Each of the lighting scenarios is included in the `in/lights` directory. The script `scripts/run_scenarios.sh` can be used to simulate all of them using the included configuration files using

```bash
 ./scripts/run_scenarios.sh ./in/lights/ ./in/template.main.json5
```

Once you have got all of the simulations completed, with the outputs automatically deposited into the  `out/` directory, you need to extract the 2D planes from voxel data at isoheights of 0m, 4m, and 10m using the included Python script by running

```bash
./scripts/extract_scenario_isoheights.sh ./out/*/energy_density.nc
```

**Note:** this will setup the Python environment for this code in `scripts/venv`. 

To produce the random walks from this input, run the following commands

```bash
# First, change directory to the isoheight planes folder.
cd isoheight_planes

# Now run the script upon the planes. 
../grid_walker-0.1.0/scr/run_all.sh ../in/grid_walker.template.toml
```

Once the random walks are completed, the resulting walk results can be found in the `isoheight_planes/walk/` directory. 
